==> jc-1.4.0.tar.gz: gnu/xml/pipeline/PipelineFactory__24Pipeline.h <==
// class gnu.xml.pipeline.PipelineFactory$Pipeline

// class file dependencies
// @dep_class b1efc8202b923321 gnu_xml_pipeline_PipelineFactory__24Pipeline
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_
#define _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;

typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$_init$c2bf40550e479808(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$createPipeline$bf8faa287ba34bf2(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method_info$createPipeline$bf8faa287ba34bf2;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods {
	struct _jc_object	*(*createPipeline$bf8faa287ba34bf2)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods	gnu_xml_pipeline_PipelineFactory__24Pipeline;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs {
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	*stage;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*rest;
	struct _jc_object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs {
    _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs	gnu_xml_pipeline_PipelineFactory__24Pipeline;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs	gnu_xml_pipeline_PipelineFactory__24Pipeline;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object {
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory__24Pipeline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/PipelineFactory__24Pipeline.h <==
// class gnu.xml.pipeline.PipelineFactory$Pipeline

// class file dependencies
// @dep_class b1efc8202b923321 gnu_xml_pipeline_PipelineFactory__24Pipeline
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_
#define _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;

typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$_init$c2bf40550e479808(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$createPipeline$bf8faa287ba34bf2(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method_info$createPipeline$bf8faa287ba34bf2;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods {
	struct _jc_object	*(*createPipeline$bf8faa287ba34bf2)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vmethods	gnu_xml_pipeline_PipelineFactory__24Pipeline;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs {
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	*stage;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*rest;
	struct _jc_object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs {
    _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_refs	gnu_xml_pipeline_PipelineFactory__24Pipeline;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$sub_nonrefs	gnu_xml_pipeline_PipelineFactory__24Pipeline;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object {
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$vtype _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory__24Pipeline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory__24Pipeline_H_ */
